	; Display some color bars for Tyler.
	org 0x100
	; Seven 100% Saturation/Brightness bars.
	; Other popular values are 95/100 and 100/75.
	; By Eric Auer 2004 for Tyler and NewOS. Public Domain.

%define animate 1	; comment out to avoid animation
%define animstep 5	; how far to scroll every 55msec
%define cmdline 1	; comment out to avoid command line reading

start:	mov ax,0x0013	; set video mode 0x13: MCGA 320x200x256
	int 0x10	; VGA BIOS
	cld

%ifdef cmdline
	xor cx,cx
	mov si,0x80	; command line len + args
	mov di,msgtext	; string to be displayed
	lodsb
	or al,al	; any args?
	jz nocmdline
	mov al,0x0d	; termination char
	mov [si+40],al	; limit to 40 chars
cmcnt:	lodsb
	cmp al,0x0d	; done?
	jz cmdend
	inc cx		; else count
	stosb		; and copy
	jmp short cmcnt
cmdend:	mov [msglen],cx
	mov al,0	; terminate string
	stosb
	mov ax,40	; available columns
	sub ax,cx	; - used columns = margins
	shr ax,1	; / 2 = one margin
	mov [msgcol],al	; position for centered display
nocmdline:
%endif

	mov ax,0xa000	; frame buffer segment
	mov es,ax	; stosw target segment
	xor di,di	; start at top left pixel
	call image	; draw one frame
	sub di,320*200
	xor ax,ax	; function 0: wait for a key
	int 0x16	; keyboard BIOS functions

%ifdef animate
anim8:	add di,animstep	; animate
	call image
	sub di,320*200
	call dly
	or di,di
	jnz anim8
%endif

fine:	mov ax,3	; set video mode 3: 80x25 color text
	int 0x10	; VGA BIOS
	mov ax,0x4c00	; return with errorlevel 0
	int 0x21	; DOS


idone:	ret
nextline:
image:	mov si,cols	; table pointer
	cmp di,150*320	; 75% of screen filled?
	jb line		; else continue
	cmp di,(150*320) + 319
	jb skip12	; then skip 1/8 of the screen
	cmp di,200*320	; >= 100% filled?
	jae idone	; then done
	jmp short line	; else continue filling
skip12:	call message
	add di,25*320	; skip 12.5% of screen
	
line:	lodsw		; AL is color, AH is count
	or al,al	; fell off the end?
	jz nextline	; then continue with next line
	mov cl,ah
	mov ch,0	; CX is now the count
	rep stosb	; draw CX pixels of color AL
	jmp short line	; repeat for next bar



message:
	push es
	mov ax,0x1300	; write string (0x1301: write char/attrib pairs)
	mov bx,0x000f	; write page 0 (BH), color white (BL is 0x0f)
	mov cx,[msglen]	; size of string
	mov dh,20	; text row number, 0 based
	mov dl,[msgcol]	; column number, 0 based
	push cs
	pop es		; string segment
	mov bp,msgtext	; place of the string
	int 0x10	; VGA BIOS
	pop es
	ret


dly:	push es		; wait until timer counter changes
	push ax
	mov ax,0x40	; BIOS data seg
	mov es,ax
	mov ax,[es:0x6c]	; timer
dloop:	hlt
	cmp ax,[es:0x6c]
	jz dloop
	pop ax
	pop es
	ret		; at most 55 msec elapsed now


cols:	; W 15  Y 14  C 11  G 10  M 13  R 12  B 09
	; each bar is 45-46 pixels wide, reaching a sum of 320.
	db 15, 45, 14, 46, 11, 46, 10, 46, 13, 46, 12, 46, 09, 45, 0, 0

msgcol:	db 17		; 0-based column of message
msglen:	dw 6		; size of message
msgtext:		; the message
	db "NewOS!",0
